﻿<?xml version="1.0"?>
<!-- 
      This style sheet can be used to combine a ANC header file, and the bits of standoff the header uses, into 
      a single XML file. 
       
       Author: Keith Suderman       
       -->
<xsl:stylesheet version="1.0"
	xmlns="http://www.xces.org/schema/2003" 
	xmlns:xlink="http://www.w3.org/1999/xlink"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www/w3/org/2001/XMLSchema-instance"
	xmlns:xces="http://www.xces.org/schema/2003"
	exclude-result-prefixes="xces xsi xlink">
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<!-- You may need to change this to point to the correct location of the publicationStmt.xml file. -->
	<xsl:variable name="pubStmt">publicationStmt.xml</xsl:variable>
	<!-- You may need to change this to point to the correct location of the respStmt.xml file. -->
	<xsl:variable name="respStmt">respStmt.xml</xsl:variable>
	<!--
			No changes should be needed below this point.
	-->
	<!-- Start the ball rolling. -->
	<xsl:template match="/">
		<xsl:apply-templates/>
	</xsl:template>
	<!-- Rename the root element of each document. -->
	<xsl:template match="xces:doc">		
		<cesDoc>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-templates/>
		</cesDoc>
	</xsl:template>
	<!-- Import and process the header. -->
	<xsl:template match="xces:xcesHeader">
		<xsl:apply-templates select="document(@xlink:href)" mode="header"/>
	</xsl:template>
	<!-- Rename the header element. -->
	<xsl:template match="xces:header" mode="header">
		<cesHeader>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-templates mode="header"/>
		</cesHeader>
	</xsl:template>
	<!-- We need to modify the tagUsages since we've renamed some elements  -->
	<xsl:template match="xces:tagUsage" mode="header">
		<tagUsage>
			<xsl:choose>
				<xsl:when test="@gi='doc'"><xsl:attribute name="gi">cesDoc</xsl:attribute></xsl:when>
				<xsl:when test="@gi='xcesHeader'"><xsl:attribute name="gi">cesHeader</xsl:attribute></xsl:when>
				<xsl:otherwise><xsl:copy-of select="@gi"/></xsl:otherwise>
			</xsl:choose>
			<xsl:copy-of select="@occurs"/>			
		</tagUsage>
	</xsl:template>
	<!-- Import the respStmt and publicationStmt files.  Otherwise just make a copy of the current element. -->
	<xsl:template match="xces:respStmtLink" mode="header">
		<xsl:apply-templates select="document($respStmt)" mode="header"/>
	</xsl:template>
	<xsl:template match="xces:publicationStmtLink" mode="header">
		<xsl:apply-templates select="document($pubStmt)" mode="header"/>
	</xsl:template>
	<xsl:template match="xces:domain|xces:subdomain|xces:subject|xces:audience|xces:medium" mode="header">
		<catRef>
			<xsl:attribute name="scheme"><xsl:value-of select="local-name()"/></xsl:attribute>
			<xsl:attribute name="target"><xsl:value-of select="translate(., ' ', '_')"/></xsl:attribute>
		</catRef>
	</xsl:template>
	<!-- Move the annotations block into the profileDesc -->
	<xsl:template match="xces:profileDesc" mode="header">
		<xsl:element name="{local-name()}">
			<xsl:apply-templates select="@*"/>
			<xsl:apply-templates mode="header"/>
			<xsl:element name="annotations">
					<![CDATA[
					]]>
					<xsl:apply-templates select="//xces:annotation" mode="header"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- and supress the annotations block elsewhere -->
	<xsl:template match="xces:annotations" mode="header"/>
	
	<xsl:template match="*" mode="header">
		<xsl:element name="{local-name()}">
			<xsl:apply-templates select="@*"/>
			<xsl:apply-templates mode="header"/>
		</xsl:element>
	</xsl:template>
	<!-- Fix the textClass block in the header. -->
	<!-- Replace "turn" elements with "u" (utterance) elements. -->
	<xsl:template match="xces:turn">
		<u>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-templates/>
		</u>
	</xsl:template>
	<!-- Make a copy of all other elements. -->
	<xsl:template match="*">
		<xsl:element name="{local-name()}">
			<xsl:apply-templates select="@*"/>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	<!-- Copy all attributes, but strip out those pesky schemaLocation attributes. -->
	<xsl:template match="@*">
		<xsl:choose>
			<xsl:when test="name() = 'xsi:schemaLocation'"/>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
